From: <gregkh@linuxfoundation.org>
To: imre.deak@intel.com, gregkh@linuxfoundation.org, tmb@mageia.org
Cc: <stable@vger.kernel.org>, <stable-commits@vger.kernel.org>
Subject: Patch "drm/i915/gen9: Fix PCODE polling timeout in stable backport" has been added to the 4.9-stable tree
Date: Tue, 17 Jan 2017 17:12:40 +0100 [thread overview]
Message-ID: <148466956072245@kroah.com> (raw)
In-Reply-To: <20170116165946.GB4514@ideak-desk.fi.intel.com>
This is a note to let you know that I've just added the patch titled
drm/i915/gen9: Fix PCODE polling timeout in stable backport
to the 4.9-stable tree which can be found at:
http://www.kernel.org/git/?p=linux/kernel/git/stable/stable-queue.git;a=summary
The filename of the patch is:
drm-i915-gen9-fix-pcode-polling-timeout-in-stable-backport.patch
and it can be found in the queue-4.9 subdirectory.
If you, or anyone else, feels it should not be added to the stable tree,
please let <stable@vger.kernel.org> know about it.
>From imre.deak@intel.com Tue Jan 17 16:22:12 2017
From: Imre Deak <imre.deak@intel.com>
Date: Mon, 16 Jan 2017 18:59:46 +0200
Subject: drm/i915/gen9: Fix PCODE polling timeout in stable backport
To: Thomas Backlund <tmb@mageia.org>
Cc: gregkh@linuxfoundation.org, arthur.j.runyan@intel.com, chris@chris-wilson.co.uk, jani.nikula@intel.com, stable@vger.kernel.org, ville.syrjala@linux.intel.com, stable-commits@vger.kernel.org
Message-ID: <20170116165946.GB4514@ideak-desk.fi.intel.com>
Content-Disposition: inline
From: Imre Deak <imre.deak@intel.com>
The backport of
2c7d0602c - "Fix PCODE polling during CDCLK change notification"
to the 4.9 stable tree used an incorrect timeout value. Fix this up
so the backport matches the upstream commit.
Reported-by: Thomas Backlund <tmb@mageia.org>
Signed-off-by: Imre Deak <imre.deak@intel.com>
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
drivers/gpu/drm/i915/intel_pm.c | 4 ++--
1 file changed, 2 insertions(+), 2 deletions(-)
--- a/drivers/gpu/drm/i915/intel_pm.c
+++ b/drivers/gpu/drm/i915/intel_pm.c
@@ -8015,14 +8015,14 @@ int skl_pcode_request(struct drm_i915_pr
* worst case) _and_ PCODE was busy for some reason even after a
* (queued) request and @timeout_base_ms delay. As a workaround retry
* the poll with preemption disabled to maximize the number of
* requests. Increase the timeout from @timeout_base_ms to 50ms to
* account for interrupts that could reduce the number of these
* requests.
*/
DRM_DEBUG_KMS("PCODE timeout, retrying with preemption disabled\n");
WARN_ON_ONCE(timeout_base_ms > 3);
preempt_disable();
- ret = wait_for_atomic(COND, 50);
+ ret = wait_for_atomic(COND, 10);
preempt_enable();
out:
Patches currently in stable-queue which might be from imre.deak@intel.com are
queue-4.9/drm-i915-gen9-fix-pcode-polling-during-sagv-disabling.patch
queue-4.9/drm-i915-gen9-fix-pcode-polling-timeout-in-stable-backport.patch
prev parent reply other threads:[~2017-01-17 16:13 UTC|newest]
Thread overview: 5+ messages / expand[flat|nested] mbox.gz Atom feed top
2017-01-13 10:57 Patch "drm/i915/gen9: Fix PCODE polling during CDCLK change notification" has been added to the 4.9-stable tree gregkh
2017-01-14 19:45 ` Thomas Backlund
2017-01-16 16:59 ` Imre Deak
2017-01-17 15:22 ` Greg KH
2017-01-17 16:12 ` gregkh [this message]
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=148466956072245@kroah.com \
--to=gregkh@linuxfoundation.org \
--cc=imre.deak@intel.com \
--cc=stable-commits@vger.kernel.org \
--cc=stable@vger.kernel.org \
--cc=tmb@mageia.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -8015,14 +8015,14 @@ int skl_pcode_request(struct drm_i915_pr
* (queued) request and @timeout_base_ms delay. As a workaround retry
* the poll with preemption disabled to maximize the number of
- * requests. Increase the timeout from @timeout_base_ms to 50ms to
+ * requests. Increase the timeout from @timeout_base_ms to 10ms to
* account for interrupts that could reduce the number of these
* requests.
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.